ecma_tests
open | /demo/@@kukittestsuite/runner.html |
assertTextPresent | Run Testcases |
click | css=a[href="javascript:runTestCases();"] |
assertText | //div[@id='kukit.UtilsTestCase']/div | OK!
assertText | //div[@id='kukit.BaseURLTestCase']/div | OK!
assertText | //div[@id='kukit.RequestManagerTestCase']/div | OK!
assertText | //div[@id='kukit.TokenizerTestCase']/div | OK!
assertText | //div[@id='kukit.KssParserTestCase']/div | OK!
assertText | //div[@id='kukit.KssParserSelectorTestCase']/div | OK!
assertText | //div[@id='kukit.KssParserValueProvidersCheckTestCase']/div | OK!
assertText | //div[@id='kukit.KssParserSelectorsTestCase']/div | OK!